==> api-0.8.2-sources.jar: eu/fispace/api/common/NotificationMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.07.08 a las 03:34:38 PM CEST 
//


package eu.fispace.api.common;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * 
 * 					TODO
 * 				
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "fispaceUserId",
    "type",
    "message",
    "created"
})
@XmlRootElement(name = "NotificationMessage")
public class NotificationMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected String fispaceUserId;
    @XmlElement(required = true)
    protected String type;
    @XmlElement(required = true)
    protected String message;
    @XmlElement(required = true)
    protected String created;

    /**
     * Obtiene el valor de la propiedad fispaceUserId.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFispaceUserId() {
        return fispaceUserId;
    }

    /**
     * Define el valor de la propiedad fispaceUserId.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFispaceUserId(String value) {
        this.fispaceUserId = value;
    }

    public boolean isSetFispaceUserId() {
        return (this.fispaceUserId!= null);
    }

    /**
     * Obtiene el valor de la propiedad type.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Define el valor de la propiedad type.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    public boolean isSetType() {
        return (this.type!= null);
    }

    /**
     * Obtiene el valor de la propiedad message.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessage() {
        return message;
    }

    /**
     * Define el valor de la propiedad message.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessage(String value) {
        this.message = value;
    }

    public boolean isSetMessage() {
        return (this.message!= null);
    }

    /**
     * Obtiene el valor de la propiedad created.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCreated() {
        return created;
    }

    /**
     * Define el valor de la propiedad created.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCreated(String value) {
        this.created = value;
    }

    public boolean isSetCreated() {
        return (this.created!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            String theFispaceUserId;
            theFispaceUserId = this.getFispaceUserId();
            strategy.appendField(locator, this, "fispaceUserId", buffer, theFispaceUserId);
        }
        {
            String theType;
            theType = this.getType();
            strategy.appendField(locator, this, "type", buffer, theType);
        }
        {
            String theMessage;
            theMessage = this.getMessage();
            strategy.appendField(locator, this, "message", buffer, theMessage);
        }
        {
            String theCreated;
            theCreated = this.getCreated();
            strategy.appendField(locator, this, "created", buffer, theCreated);
        }
        return buffer;
    }

    public NotificationMessage withFispaceUserId(String value) {
        setFispaceUserId(value);
        return this;
    }

    public NotificationMessage withType(String value) {
        setType(value);
        return this;
    }

    public NotificationMessage withMessage(String value) {
        setMessage(value);
        return this;
    }

    public NotificationMessage withCreated(String value) {
        setCreated(value);
        return this;
    }

}

==> api-0.9.0-sources.jar: eu/fispace/api/common/NotificationMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.07.17 a las 08:57:14 AM CEST 
//


package eu.fispace.api.common;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * 
 * 					This class represents a notification message (to be) sent to the FIspace front-end, 
 * 					which shall be displayed in the notification bar in the GUI. It should be used by 
 * 					FIspace components or external systems who want to send a notification to a specific 
 * 					FIspace user via the GUI.
 * 				
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "fispaceUserId",
    "type",
    "message",
    "created"
})
@XmlRootElement(name = "NotificationMessage")
public class NotificationMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected String fispaceUserId;
    @XmlElement(required = true)
    protected String type;
    @XmlElement(required = true)
    protected String message;
    @XmlElement(required = true)
    protected String created;

    /**
     * Obtiene el valor de la propiedad fispaceUserId.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFispaceUserId() {
        return fispaceUserId;
    }

    /**
     * Define el valor de la propiedad fispaceUserId.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFispaceUserId(String value) {
        this.fispaceUserId = value;
    }

    public boolean isSetFispaceUserId() {
        return (this.fispaceUserId!= null);
    }

    /**
     * Obtiene el valor de la propiedad type.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Define el valor de la propiedad type.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    public boolean isSetType() {
        return (this.type!= null);
    }

    /**
     * Obtiene el valor de la propiedad message.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessage() {
        return message;
    }

    /**
     * Define el valor de la propiedad message.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessage(String value) {
        this.message = value;
    }

    public boolean isSetMessage() {
        return (this.message!= null);
    }

    /**
     * Obtiene el valor de la propiedad created.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCreated() {
        return created;
    }

    /**
     * Define el valor de la propiedad created.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCreated(String value) {
        this.created = value;
    }

    public boolean isSetCreated() {
        return (this.created!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            String theFispaceUserId;
            theFispaceUserId = this.getFispaceUserId();
            strategy.appendField(locator, this, "fispaceUserId", buffer, theFispaceUserId);
        }
        {
            String theType;
            theType = this.getType();
            strategy.appendField(locator, this, "type", buffer, theType);
        }
        {
            String theMessage;
            theMessage = this.getMessage();
            strategy.appendField(locator, this, "message", buffer, theMessage);
        }
        {
            String theCreated;
            theCreated = this.getCreated();
            strategy.appendField(locator, this, "created", buffer, theCreated);
        }
        return buffer;
    }

    public NotificationMessage withFispaceUserId(String value) {
        setFispaceUserId(value);
        return this;
    }

    public NotificationMessage withType(String value) {
        setType(value);
        return this;
    }

    public NotificationMessage withMessage(String value) {
        setMessage(value);
        return this;
    }

    public NotificationMessage withCreated(String value) {
        setCreated(value);
        return this;
    }

}
